@@ -14,12 +14,17 @@
 """
 import logging as log
 import os
+from os.path import basename
 from typing import Any, Optional
 
+from clitt.core.tui.minput.input_validator import InputValidator
+from clitt.core.tui.minput.minput import MenuInput, minput
 from datasource.firebase.firebase_configuration import FirebaseConfiguration
 from hspylib.core.config.app_config import AppConfigs
+from hspylib.core.config.properties import Properties
 from hspylib.core.metaclass.singleton import Singleton
-from hspylib.core.tools.commons import dirname, file_is_not_empty, sysout
+from hspylib.core.tools.commons import dirname, file_is_not_empty, sysout, touch_file
+from hspylib.core.tools.dict_tools import get_or_default_by_key
 from requests.structures import CaseInsensitiveDict
 
 from firebase.core.firebase_auth import FirebaseAuth
@@ -37,7 +42,7 @@ class AgentConfig(metaclass=Singleton):
             log.debug("Found and loaded a Firebase configuration: %s", self)
 
     def __str__(self) -> str:
-        return str(self.firebase_configs or "")
+        return str(self.firebase_configs)
 
     def __repr__(self):
         return str(self)
@@ -70,14 +75,54 @@ class AgentConfig(metaclass=Singleton):
 
     def prompt(self) -> None:
         """Create a new firebase configuration by prompting the user for information."""
-        config = CaseInsensitiveDict()
-        sysout("### Firebase setup")
-        sysout("-=" * 15)
-        config["UID"] = self.uuid
-        config["PROJECT_ID"] = self.project_id
-        config["EMAIL"] = self.email
-        config["DATABASE"] = self.database
-        self.setup(dirname(self.filename), self.filename, config)
+        config = None
+        if os.path.exists(self.filename):
+            with open(self.filename, "r") as fh_configs:
+                config = Properties.read_properties(fh_configs)
+        else:
+            touch_file(self.filename)
+        config = config if config else CaseInsensitiveDict()
+        sysout("%ORANGE%### Firebase setup")
+        sysout("-=" * 15 + "%EOL%%%NC%")
+        # fmt: off
+        form_fields = MenuInput.builder() \
+            .field() \
+                .label('UID') \
+                .validator(InputValidator.words()) \
+                .min_max_length(30, 30) \
+                .dest("uid") \
+                .value(get_or_default_by_key(config, 'UID', '')) \
+                .build() \
+            .field() \
+                .label('PROJECT_ID') \
+                .validator(InputValidator.anything()) \
+                .min_max_length(1, 50) \
+                .dest("project_id") \
+                .value(get_or_default_by_key(config, 'PROJECT_ID', '')) \
+                .build() \
+            .field() \
+                .label('EMAIL') \
+                .validator(InputValidator.anything()) \
+                .min_max_length(1, 50) \
+                .dest("email") \
+                .value(get_or_default_by_key(config, 'EMAIL', '')) \
+                .build() \
+            .field() \
+                .label('DATABASE') \
+                .validator(InputValidator.anything()) \
+                .min_max_length(1, 50) \
+                .dest("database") \
+                .value(get_or_default_by_key(config, 'DATABASE', '')) \
+                .build() \
+            .build()
+        result = minput(form_fields)
+        # fmt: on
+        if result:
+            config["UID"] = result.uid
+            config["PROJECT_ID"] = result.project_id
+            config["EMAIL"] = result.email
+            config["DATABASE"] = result.database
+        self.setup(dirname(self.filename), basename(self.filename), config)
 
     @property
     def filename(self) -> str:
@@ -87,27 +132,27 @@ class AgentConfig(metaclass=Singleton):
 
     @property
     def project_id(self) -> Optional[str]:
-        """Return the firebase project ID."""
+        """Return the firebase Project ID."""
         pid = self.app_configs["hhs.firebase.project.id"]
-        return pid if pid else input("Please type your project ID: ")
+        return pid
 
     @property
-    def uuid(self) -> Optional[str]:
-        """Return the firebase user ID."""
+    def uid(self) -> Optional[str]:
+        """Return the firebase User ID."""
         uid = self.app_configs["hhs.firebase.user.uid"]
-        return uid if uid else input("Please type your user UID: ")
+        return uid
 
     @property
     def email(self) -> Optional[str]:
-        """Return the firebase username."""
-        em = self.app_configs["hhs.firebase.email"]
-        return em if em else input("Please type your Email: ")
+        """Return the firebase user's email."""
+        email = self.app_configs["hhs.firebase.email"]
+        return email
 
     @property
     def database(self) -> Optional[str]:
         """Return the firebase project database name."""
         database = self.app_configs["hhs.firebase.database"]
-        return database if database else input("Please type your database Name: ")
+        return database
 
     def url(self, db_alias: str) -> str:
         """Return the firebase project URL"""
@@ -121,5 +166,5 @@ class AgentConfig(metaclass=Singleton):
     def _save(self) -> None:
         """Save current firebase configuration"""
         with open(self.filename, "w+", encoding="utf-8") as f_config:
-            f_config.write(str(self))
+            f_config.write(f"{str(self)}{os.linesep}")
             sysout(f"Firebase configuration saved => {self.filename} !")
