@@ -2,9 +2,8 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
-   @project: HSPyLib
-   @package: hspylib.app.firebase.core
+   @project: HSPyLib-Firebase
+   @package: firebase.core
       @file: firebase.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -30,7 +29,9 @@ class Firebase:
 
     def __init__(self) -> None:
         self.processor = FileProcessor()
-        self.agent_config = AgentConfig()
+        filename = os.environ.get(
+            "HHS_FIREBASE_CONFIG_FILE", f"{os.environ.get('HOME', os.curdir)}/firebase.properties")
+        self.agent_config = AgentConfig(filename)
 
     def __str__(self):
         return str(self.agent_config)
